/*
   Name:    "ShowSize-oo.rex"

   Invoke:  "java com.ibm.bsf.Main -lang rexx -in ShowSize-oo.rex"
                or
            "java com.ibm.bsf.Main            -in ShowSize-oo.rex"
                or
             "rexxj ShowSize-oo.rex"
                or
             "rexx ShowSize-oo.rex"

   Purpose:  create a little resizable window with a push button to reveal the actual
             size; adds EventListeners in order for Rexx to be notified, if a button
             is pressed or the Window closed (by pressing the System close button)

             This version works also, if called from the command line, as it is able
             to load Java and the bsf4rexx support by itself.

   Needs:    IBM's "Bean Scripting Framework" (BSF)
             (cf. "http://oss.software.ibm.com/developerworks/projects/bsf")

             and the package "bsf4rexx", the "Augsburg version" as of 2003
             (cf. "http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/Entwicklung.html")

   Date:    2001-04-18, 2003-01-23

   Author:   Rony G. Flatscher, University of Essen, WU Wien University,
             derived from Peter Kalender's work for the "Essener Ski Seminar",
             University of Essen (Oct 2000 to Feb 2001)
             (cf. "http://nestroy.wi-inf.uni-essen.de/Lv/seminare/ws0001/index-e.html");
*/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

.bsf~import("awtFrame",  "java.awt.Frame")      -- import Java class
.bsf~import("awtButton", "java.awt.Button")     -- import Java class
.bsf~import("awtLabel",  "java.awt.Label" )     -- import Java class

window = .awtFrame~new("String", "Show Size")
window~bsf.addEventListener('window', 'windowClosing', 'call BSF "exit"')

button = .awtButton~new('String', 'Press me!')
button ~ bsf.addEventListener('action', '', 'call ShowSize window, label')

label = .awtLabel~new
label~setAlignment("I", label~bsf.getFieldValue("CENTER"))

window ~~add("string", "Center", "object", label) ~~add("St", "South", "O", button) ~~pack
window ~~setSize("i", 250, "i", 150) ~~setLocation("i", 100, "i", 100) ~~show ~~toFront

secs=3
info="sleeping" secs  "seconds ..."
label~setText("str", info)
say info
call bsf 'sleep', secs  /* sleep i seconds using bsf4rexx       */

do i=100 to 300 by 10   -- animate the window a little bit
   call bsf 'sleep', .1         /* sleep i seconds using bsf4rexx       */
   window  ~setLocation("int", i, "int", (i/3)%1)
   window ~~setSize("int", (i*.9)%1, "int", 100+i%3 ) ~~show
   call showSize window, label
end
call showSize window, label

do forever
        /* using the OO-version a Java "null" string will be translated automatically
        into the Object Rexx equivalent, i.e. .nil        */
   a = .bsf~pollEventText(1000) /* wait for an eventText to be sent,
                                   after 1 second return anyway */
   if a=.nil then say "Rexx: no eventText so far ..."
   else
   do
      say "received the following eventText: ["a"]"
      interpret a               /* execute as a Rexx program            */
      if result= "SHUTDOWN, REXX !" then leave  /* JVM will be shutdown */
      say "Rexx: sleeping" secs "secs"
      call bsf 'sleep', secs    /* sleep i seconds using bsf4rexx       */
      say "Rexx: awakened!"
   end
end

exit


ShowSize: procedure
   use arg window, label                        /* get proxy objects    */

   parse value (window~getSize~toString) with "width=" width ",height=" height "]"
   label~setText("String", width "/" height )
   return

::requires "BSF.cls"    -- include direct Object Rexx BSF support

